==> CDPKit-1.0.1.tar.gz: CDPKit-1.0.1/Libs/C++/Source/CDPL/Chem/AtomContainerAtomTypeMaskFunction.cpp <==
/* 
 * AtomContainerAtomTypeMaskFunction.cpp 
 *
 * This file is part of the Chemical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#include "StaticInit.hpp"

#include "CDPL/Chem/AtomContainerFunctions.hpp"
#include "CDPL/Chem/AtomFunctions.hpp"


using namespace CDPL; 


std::size_t Chem::createAtomTypeMask(const Chem::AtomContainer& cntnr, Util::BitSet& mask, unsigned int type, bool reset)
{
    std::size_t num_atoms = cntnr.getNumAtoms();

    if (mask.size() < num_atoms)
        mask.resize(num_atoms);

    if (reset)
        mask.reset();

    std::size_t num_bits = 0;

    for (std::size_t i = 0; i < num_atoms; i++) {
        const Atom& atom = cntnr.getAtom(i);
        
        if (getType(atom) == type) {
            mask.set(i);
            num_bits++;
        }
    }

    return num_bits;
}

==> CDPKit-1.1.0.tar.gz: CDPKit-1.1.0/Libs/C++/Source/CDPL/Chem/AtomContainerAtomTypeMaskFunction.cpp <==
/* 
 * AtomContainerAtomTypeMaskFunction.cpp 
 *
 * This file is part of the Chemical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#include "StaticInit.hpp"

#include "CDPL/Chem/AtomContainerFunctions.hpp"
#include "CDPL/Chem/AtomFunctions.hpp"
#include "CDPL/Chem/UtilityFunctions.hpp"


using namespace CDPL; 


std::size_t Chem::createAtomTypeMask(const Chem::AtomContainer& cntnr, Util::BitSet& mask, unsigned int type, bool reset, bool strict)
{
    std::size_t num_atoms = cntnr.getNumAtoms();

    if (mask.size() < num_atoms)
        mask.resize(num_atoms);

    if (reset)
        mask.reset();

    std::size_t num_bits = 0;

    for (std::size_t i = 0; i < num_atoms; i++) {
        const Atom& atom = cntnr.getAtom(i);

        if (strict) {
            if (type != getType(atom))
                continue;
            
        } else if (!atomTypesMatch(type, getType(atom)))
            continue;
              
        mask.set(i);
        num_bits++;
    }

    return num_bits;
}
